from setuptools import setup

setup(
    name='upload_hdkylin',
    version='0.0.1',
    packages=['utils', 'utils.site', 'utils.signer', 'utils.pathinfo', 'utils.rss_ctrl', 'utils.uploader',
              'utils.mediafile', 'utils.para_ctrl', 'utils.img_upload', 'utils.edittorrent', 'utils.seed_machine'],
    url='',
    license='',
    author='moyan',
    author_email='',
    description='一键转种'
)
